==> cdk-lambda-subminute-2.0.148-sources.jar: io/github/hsiehshujeng/cdk/lambda/subminute/SubminuteStateMachine.java <==
package io.github.hsiehshujeng.cdk.lambda.subminute;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.80.0 (build bce6a1d)", date = "2023-05-10T01:14:30.147Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = io.github.hsiehshujeng.cdk.lambda.subminute.$Module.class, fqn = "cdk-lambda-subminute.SubminuteStateMachine")
public class SubminuteStateMachine extends software.constructs.Construct {

    protected SubminuteStateMachine(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SubminuteStateMachine(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public SubminuteStateMachine(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull io.github.hsiehshujeng.cdk.lambda.subminute.SubminuteStateMachineProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.StateMachine getStateMachine() {
        return software.amazon.jsii.Kernel.get(this, "stateMachine", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.stepfunctions.StateMachine.class));
    }

    /**
     * A fluent builder for {@link io.github.hsiehshujeng.cdk.lambda.subminute.SubminuteStateMachine}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.hsiehshujeng.cdk.lambda.subminute.SubminuteStateMachine> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final io.github.hsiehshujeng.cdk.lambda.subminute.SubminuteStateMachineProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new io.github.hsiehshujeng.cdk.lambda.subminute.SubminuteStateMachineProps.Builder();
        }

        /**
         * How many times you intent to execute in a minute.
         * <p>
         * Default: 6
         * <p>
         * @return {@code this}
         * @param frequency How many times you intent to execute in a minute. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder frequency(final java.lang.Number frequency) {
            this.props.frequency(frequency);
            return this;
        }

        /**
         * Seconds for an interval, the product of `frequency` and `intervalTime` should be approximagely 1 minute.
         * <p>
         * Default: 10
         * <p>
         * @return {@code this}
         * @param intervalTime Seconds for an interval, the product of `frequency` and `intervalTime` should be approximagely 1 minute. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder intervalTime(final java.lang.Number intervalTime) {
            this.props.intervalTime(intervalTime);
            return this;
        }

        /**
         * the iterator Lambda function for the target Lambda function.
         * <p>
         * @return {@code this}
         * @param iteratorFunction the iterator Lambda function for the target Lambda function. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder iteratorFunction(final software.amazon.awscdk.services.lambda.IFunction iteratorFunction) {
            this.props.iteratorFunction(iteratorFunction);
            return this;
        }

        /**
         * the name of the state machine.
         * <p>
         * @return {@code this}
         * @param stateMachineName the name of the state machine. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder stateMachineName(final java.lang.String stateMachineName) {
            this.props.stateMachineName(stateMachineName);
            return this;
        }

        /**
         * the Lambda function that executes your intention.
         * <p>
         * @return {@code this}
         * @param targetFunction the Lambda function that executes your intention. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetFunction(final software.amazon.awscdk.services.lambda.IFunction targetFunction) {
            this.props.targetFunction(targetFunction);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.hsiehshujeng.cdk.lambda.subminute.SubminuteStateMachine}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public io.github.hsiehshujeng.cdk.lambda.subminute.SubminuteStateMachine build() {
            return new io.github.hsiehshujeng.cdk.lambda.subminute.SubminuteStateMachine(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> cdk-lambda-subminute-2.0.417-sources.jar: io/github/hsiehshujeng/cdk/lambda/subminute/SubminuteStateMachine.java <==
package io.github.hsiehshujeng.cdk.lambda.subminute;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-03-30T01:02:55.413Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = io.github.hsiehshujeng.cdk.lambda.subminute.$Module.class, fqn = "cdk-lambda-subminute.SubminuteStateMachine")
public class SubminuteStateMachine extends software.constructs.Construct {

    protected SubminuteStateMachine(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SubminuteStateMachine(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public SubminuteStateMachine(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull io.github.hsiehshujeng.cdk.lambda.subminute.SubminuteStateMachineProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.StateMachine getStateMachine() {
        return software.amazon.jsii.Kernel.get(this, "stateMachine", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.stepfunctions.StateMachine.class));
    }

    /**
     * A fluent builder for {@link io.github.hsiehshujeng.cdk.lambda.subminute.SubminuteStateMachine}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.hsiehshujeng.cdk.lambda.subminute.SubminuteStateMachine> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final io.github.hsiehshujeng.cdk.lambda.subminute.SubminuteStateMachineProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new io.github.hsiehshujeng.cdk.lambda.subminute.SubminuteStateMachineProps.Builder();
        }

        /**
         * How many times you intent to execute in a minute.
         * <p>
         * Default: 6
         * <p>
         * @return {@code this}
         * @param frequency How many times you intent to execute in a minute. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder frequency(final java.lang.Number frequency) {
            this.props.frequency(frequency);
            return this;
        }

        /**
         * Seconds for an interval, the product of <code>frequency</code> and <code>intervalTime</code> should be approximagely 1 minute.
         * <p>
         * Default: 10
         * <p>
         * @return {@code this}
         * @param intervalTime Seconds for an interval, the product of <code>frequency</code> and <code>intervalTime</code> should be approximagely 1 minute. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder intervalTime(final java.lang.Number intervalTime) {
            this.props.intervalTime(intervalTime);
            return this;
        }

        /**
         * the iterator Lambda function for the target Lambda function.
         * <p>
         * @return {@code this}
         * @param iteratorFunction the iterator Lambda function for the target Lambda function. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder iteratorFunction(final software.amazon.awscdk.services.lambda.IFunction iteratorFunction) {
            this.props.iteratorFunction(iteratorFunction);
            return this;
        }

        /**
         * the name of the state machine.
         * <p>
         * @return {@code this}
         * @param stateMachineName the name of the state machine. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder stateMachineName(final java.lang.String stateMachineName) {
            this.props.stateMachineName(stateMachineName);
            return this;
        }

        /**
         * the Lambda function that executes your intention.
         * <p>
         * @return {@code this}
         * @param targetFunction the Lambda function that executes your intention. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetFunction(final software.amazon.awscdk.services.lambda.IFunction targetFunction) {
            this.props.targetFunction(targetFunction);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.hsiehshujeng.cdk.lambda.subminute.SubminuteStateMachine}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public io.github.hsiehshujeng.cdk.lambda.subminute.SubminuteStateMachine build() {
            return new io.github.hsiehshujeng.cdk.lambda.subminute.SubminuteStateMachine(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
